polyfemos.data.statistics — polyfemos 0.3.29 documentation

# polyfemos.data.statistics

Functions for retrieving statistical info about the data

copyright

  2019, University of Oulu, Sodankyla Geophysical Observatory

license

  GNU Lesser General Public License v3.0 or later (https://spdx.org/licenses/LGPL-3.0-or-later.html)

Public Functions

`polyfemos.data.statistics.` `get_statistics_dict`(data, thresholds=[], unit=nan)

  Calculates statistical parameters of the given data

  Parameters

    - data (list) – 1-D data, without nans

    - thresholds (list, optional) – Upper and lower thresholds as a list of at most two entries, used to calculate broken threshold percentage

    - unit (str, optional) – The unit of the data

  Return type

    dict

  Returns

    dictionary containing statistical information of the given data

`polyfemos.data.statistics.` `get_statistics_table`(dict_)
  Parameters

    dict_ (dict) – statistics dictionary

  Return type

    list

  Returns

    a 2-D list containing statistical information about the selected parameter during selected timespan, each row in table consists of parameter, value and unit